@@ -4,7 +4,6 @@ import (
 	"bytes"
 	"encoding/json"
 	"encoding/xml"
-	"errors"
 	"fmt"
 	"github.com/PuerkitoBio/goquery"
 	"github.com/antchfx/xmlquery"
@@ -66,9 +65,13 @@ func FormatXml(reader io.Reader, writer io.Writer, indent string, colors int) er
 
 	level := 0
 	hasContent := false
-	nsAliases := map[string]string{}
+	nsAliases := map[string]string{"http://www.w3.org/XML/1998/namespace": "xml"}
 	lastTagName := ""
 	startTagClosed := true
+	newline := "\n"
+	if indent == "" {
+		newline = ""
+	}
 
 	if ColorsDefault != colors {
 		color.NoColor = colors == ColorsDisabled
@@ -100,14 +103,14 @@ func FormatXml(reader io.Reader, writer io.Writer, indent string, colors int) er
 				_, _ = fmt.Fprintf(writer, " %s%s", attrComponents[0], attrColor("="+attrComponents[1]))
 			}
 
-			_, _ = fmt.Fprintf(writer, "%s\n", tagColor("?>"))
+			_, _ = fmt.Fprint(writer, tagColor("?>"), newline)
 		case xml.StartElement:
 			if !startTagClosed {
 				_, _ = fmt.Fprint(writer, tagColor(">"))
 				startTagClosed = true
 			}
 			if level > 0 {
-				_, _ = fmt.Fprint(writer, "\n", strings.Repeat(indent, level))
+				_, _ = fmt.Fprint(writer, newline, strings.Repeat(indent, level))
 			}
 			var attrs []string
 			for _, attr := range typedToken.Attr {
@@ -146,7 +149,7 @@ func FormatXml(reader io.Reader, writer io.Writer, indent string, colors int) er
 
 			for index, commentLine := range strings.Split(string(typedToken), "\n") {
 				if !hasContent && level > 0 {
-					_, _ = fmt.Fprint(writer, "\n", strings.Repeat(indent, level))
+					_, _ = fmt.Fprint(writer, newline, strings.Repeat(indent, level))
 				}
 				if index == 0 {
 					_, _ = fmt.Fprint(writer, commentColor("<!--"))
@@ -156,7 +159,7 @@ func FormatXml(reader io.Reader, writer io.Writer, indent string, colors int) er
 			_, _ = fmt.Fprint(writer, commentColor("-->"))
 
 			if level == 0 {
-				_, _ = fmt.Fprint(writer, "\n")
+				_, _ = fmt.Fprint(writer, newline)
 			}
 		case xml.EndElement:
 			level--
@@ -167,7 +170,7 @@ func FormatXml(reader io.Reader, writer io.Writer, indent string, colors int) er
 						_, _ = fmt.Fprint(writer, tagColor(">"))
 						startTagClosed = true
 					}
-					_, _ = fmt.Fprint(writer, "\n", strings.Repeat(indent, level), tagColor("</"+currentTagName+">"))
+					_, _ = fmt.Fprint(writer, newline, strings.Repeat(indent, level), tagColor("</"+currentTagName+">"))
 				} else {
 					_, _ = fmt.Fprint(writer, tagColor("/>"))
 					startTagClosed = true
@@ -179,7 +182,7 @@ func FormatXml(reader io.Reader, writer io.Writer, indent string, colors int) er
 			lastTagName = currentTagName
 		case xml.Directive:
 			_, _ = fmt.Fprint(writer, tagColor("<!"), string(typedToken), tagColor(">"))
-			_, _ = fmt.Fprint(writer, "\n", strings.Repeat(indent, level))
+			_, _ = fmt.Fprint(writer, newline, strings.Repeat(indent, level))
 		default:
 		}
 	}
@@ -192,7 +195,7 @@ func FormatXml(reader io.Reader, writer io.Writer, indent string, colors int) er
 func XPathQuery(reader io.Reader, writer io.Writer, query string, singleNode bool, options QueryOptions) (errRes error) {
 	defer func() {
 		if err := recover(); err != nil {
-			errRes = errors.New(fmt.Sprintf("XPath error: %v", err))
+			errRes = fmt.Errorf("XPath error: %v", err)
 		}
 	}()
 
@@ -247,8 +250,8 @@ func CSSQuery(reader io.Reader, writer io.Writer, query string, attr string, opt
 				var attrs []string
 				attrsStr := ""
 				for _, tagAttr := range node.Attr {
-					escapedValue, _ := escapeText(string(tagAttr.Val))
-					attrs = append(attrs, string(tagAttr.Key)+"=\""+escapedValue+"\"")
+					escapedValue, _ := escapeText(tagAttr.Val)
+					attrs = append(attrs, tagAttr.Key+"=\""+escapedValue+"\"")
 				}
 				if len(attrs) > 0 {
 					attrsStr = " " + strings.Join(attrs, " ")
@@ -280,6 +283,10 @@ func FormatHtml(reader io.Reader, writer io.Writer, indent string, colors int) e
 	hasContent := false
 	forceNewLine := false
 	selfClosingTags := getSelfClosingTags()
+	newline := "\n"
+	if indent == "" {
+		newline = ""
+	}
 
 	for {
 		token := tokenizer.Next()
@@ -299,7 +306,7 @@ func FormatHtml(reader io.Reader, writer io.Writer, indent string, colors int) e
 			_, _ = fmt.Fprint(writer, str)
 		case html.StartTagToken, html.SelfClosingTagToken:
 			if level > 0 {
-				_, _ = fmt.Fprint(writer, "\n", strings.Repeat(indent, level))
+				_, _ = fmt.Fprint(writer, newline, strings.Repeat(indent, level))
 			}
 
 			tagName, hasAttr := tokenizer.TagName()
@@ -339,7 +346,7 @@ func FormatHtml(reader io.Reader, writer io.Writer, indent string, colors int) e
 			tagName, _ := tokenizer.TagName()
 
 			if forceNewLine {
-				_, _ = fmt.Fprint(writer, "\n", strings.Repeat(indent, level))
+				_, _ = fmt.Fprint(writer, newline, strings.Repeat(indent, level))
 			}
 			_, _ = fmt.Fprint(writer, tagColor("</"+string(tagName)+">"))
 
@@ -347,17 +354,17 @@ func FormatHtml(reader io.Reader, writer io.Writer, indent string, colors int) e
 			forceNewLine = true
 		case html.DoctypeToken:
 			docType := tokenizer.Text()
-			_, _ = fmt.Fprintf(writer, "%s%s%s\n", tagColor("<!doctype "), string(docType), tagColor(">"))
+			_, _ = fmt.Fprint(writer, tagColor("<!doctype "), string(docType), tagColor(">"), newline)
 		case html.CommentToken:
 			for _, commentLine := range strings.Split(string(tokenizer.Raw()), "\n") {
 				if !hasContent && level > 0 {
-					_, _ = fmt.Fprint(writer, "\n", strings.Repeat(indent, level))
+					_, _ = fmt.Fprint(writer, newline, strings.Repeat(indent, level))
 				}
 				_, _ = fmt.Fprint(writer, commentColor(commentLine))
 			}
 
 			if level == 0 {
-				_, _ = fmt.Fprint(writer, "\n")
+				_, _ = fmt.Fprint(writer, newline)
 			}
 		}
 	}
@@ -382,6 +389,10 @@ func FormatJson(reader io.Reader, writer io.Writer, indent string, colors int) e
 	level := 0
 	suffix := ""
 	prefix := ""
+	newline := "\n"
+	if indent == "" {
+		newline = ""
+	}
 
 	for {
 		token, err := decoder.Token()
@@ -401,31 +412,31 @@ func FormatJson(reader io.Reader, writer io.Writer, indent string, colors int) e
 		case jsonTokenObjectColon:
 			suffix = ": "
 		case jsonTokenObjectComma:
-			suffix = ",\n" + strings.Repeat(indent, level)
+			suffix = "," + newline + strings.Repeat(indent, level)
 		case jsonTokenArrayComma:
-			suffix = ",\n" + strings.Repeat(indent, level)
+			suffix = "," + newline + strings.Repeat(indent, level)
 		}
 
 		switch tokenType := token.(type) {
 		case json.Delim:
 			switch rune(tokenType) {
 			case '{':
-				_, _ = fmt.Fprintf(writer, "%s%s\n", prefix, tagColor("{"))
+				_, _ = fmt.Fprint(writer, prefix, tagColor("{"), newline)
 				level++
 				suffix = strings.Repeat(indent, level)
 			case '}':
 				level--
-				_, _ = fmt.Fprintf(writer, "\n%s%s", strings.Repeat(indent, level), tagColor("}"))
+				_, _ = fmt.Fprint(writer, newline, strings.Repeat(indent, level), tagColor("}"))
 				if tokenState == jsonTokenArrayComma {
-					suffix = ",\n" + strings.Repeat(indent, level)
+					suffix = "," + newline + strings.Repeat(indent, level)
 				}
 			case '[':
-				_, _ = fmt.Fprintf(writer, "%s%s\n", prefix, tagColor("["))
+				_, _ = fmt.Fprint(writer, prefix, tagColor("["), newline)
 				level++
 				suffix = strings.Repeat(indent, level)
 			case ']':
 				level--
-				_, _ = fmt.Fprintf(writer, "\n%s%s", strings.Repeat(indent, level), tagColor("]"))
+				_, _ = fmt.Fprint(writer, newline, strings.Repeat(indent, level), tagColor("]"))
 			}
 		case string:
 			value := valueColor(token)
